@@ -58,14 +58,14 @@ class GeschaeftspartnerSchema(GeschaeftsobjektSchema):
     geschaeftspartnerrolle = fields.List(EnumField(Geschaeftspartnerrolle))
 
     # optional attributes
-    anrede = EnumField(Anrede, missing=None)
-    name2 = fields.Str(missing=None)
-    name3 = fields.Str(missing=None)
-    hrnummer = fields.Str(missing=None)
-    amtsgericht = fields.Str(missing=None)
-    kontaktweg = fields.List(EnumField(Kontaktart), missing=None)
-    umsatzsteuer_id = fields.Str(missing=None)
-    glaeubiger_id = fields.Str(missing=None)
-    e_mail_adresse = fields.Str(missing=None)
-    website = fields.Str(missing=None)
-    partneradresse = fields.Nested(AdresseSchema, missing=None)
+    anrede = EnumField(Anrede, load_default=None)
+    name2 = fields.Str(load_default=None)
+    name3 = fields.Str(load_default=None)
+    hrnummer = fields.Str(load_default=None)
+    amtsgericht = fields.Str(load_default=None)
+    kontaktweg = fields.List(EnumField(Kontaktart), load_default=None)
+    umsatzsteuer_id = fields.Str(load_default=None)
+    glaeubiger_id = fields.Str(load_default=None)
+    e_mail_adresse = fields.Str(load_default=None)
+    website = fields.Str(load_default=None)
+    partneradresse = fields.Nested(AdresseSchema, load_default=None)
